"""Module to clean-up texts on Project Gutenberg."""

from __future__ import absolute_import
from .gutenberg_cleaner import strip_headers  # noqa


__all__ = ['gutenberg_cleaner', 'io']
